@@ -6,13 +6,16 @@
 #' Extract fitted values from a sequence of regression models
 #' 
 #' Extract fitted values from a sequence of regression models, such as submodels 
-#' along a robust least angle regression sequence, or sparse least trimmed 
-#' squares regression models for a grid of values for the penalty parameter.
+#' along a robust or groupwise least angle regression sequence, or sparse least 
+#' trimmed squares regression models for a grid of values for the penalty 
+#' parameter.
 #' 
 #' @method fitted seqModel
-#' @aliases fitted.rlars
+#' @aliases fitted.rlars fitted.grplars fitted.tslarsP
 #' 
 #' @param object  the model fit from which to extract fitted values.
+#' @param p  an integer giving the lag length for which to extract fitted 
+#' values (the default is to use the optimal lag length).
 #' @param s  for the \code{"seqModel"} method, an integer vector giving the 
 #' steps of the submodels for which to extract the fitted values (the default 
 #' is to use the optimal submodel).  For the \code{"sparseLTS"} method, an 
@@ -29,7 +32,9 @@
 #' raw estimator, or \code{"both"} for the fitted values from both estimators.
 #' @param drop  a logical indicating whether to reduce the dimension to a 
 #' vector in case of only one step.
-#' @param \dots  additional arguments are currently ignored.
+#' @param \dots  for the \code{"tslars"} method, additional arguments to be 
+#' passed down to the \code{"seqModel"} method.  For the other methods, 
+#' additional arguments are currently ignored.
 #' 
 #' @return  
 #' A numeric vector or matrix containing the requested fitted values.
@@ -37,6 +42,8 @@
 #' @author Andreas Alfons
 #' 
 #' @seealso \code{\link[stats]{fitted}}, \code{\link{rlars}}, 
+#' \code{\link{grplars}}, \code{\link{rgrplars}}, \code{\link{tslarsP}}, 
+#' \code{\link{rtslarsP}}, \code{\link{tslars}}, \code{\link{rtslars}}, 
 #' \code{\link{sparseLTS}}
 #' 
 #' @example inst/doc/examples/example-fitted.R
@@ -50,6 +57,29 @@ fitted.seqModel <- function(object, s = NA, drop = !is.null(s), ...) {
 }
 
 
+#' @rdname fitted.seqModel
+#' @method fitted tslars
+#' @export
+
+fitted.tslars <- function(object, p, ...) {
+  ## initializations
+  # check lag length
+  if(missing(p) || !is.numeric(p) || length(p) == 0) {
+    p <- object$pOpt
+  } else p <- p[1]
+  pMax <- object$pMax
+  if(p < 1) {
+    p <- 1
+    warning("lag length too small, using lag length 1")
+  } else if(p > pMax) {
+    p <- pMax
+    warning(sprintf("lag length too large, using maximum lag length %d", p))
+  }
+  ## extract fitted values for specified lag length
+  fitted(object$pFit[[p]], ...)
+}
+
+
 #' @rdname fitted.seqModel
 #' @method fitted sparseLTS
 #' @export
