@@ -14,6 +14,7 @@
 
 // functions to export to R
 RcppExport SEXP R_sparseSubsets(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_h, 
-    SEXP R_subsets, SEXP R_intercept, SEXP R_eps, SEXP R_useGram);
+    SEXP R_subsets, SEXP R_normalize, SEXP R_intercept, SEXP R_eps, 
+    SEXP R_useGram);
 
 #endif
